%global glib2_version %(pkg-config --modversion glib-2.0 2>/dev/null || echo bad)
%global qmi_version %(pkg-config --modversion qmi-glib 2>/dev/null || echo bad)
%global mbim_version %(pkg-config --modversion mbim-glib 2>/dev/null || echo bad)
%global __provides_exclude ^libmm-plugin-
%bcond_without vala

Summary:       Mobile broadband modem management service
Name:          ModemManager
Version:       1.20.2
Release:       4%{?dist}
License:       GPLv2+
URL:           http://www.freedesktop.org/wiki/Software/ModemManager/
Source0:       https://gitlab.com/linux-mobile-broadband/ModemManager/-/archive/%{version}/%{name}-%{version}.tar.bz2

BuildRequires: automake autoconf libtool autoconf-archive dbus dbus-daemon make gtk-doc
BuildRequires: gobject-introspection-devel gettext-devel libqrtr-glib-devel polkit-devel
BuildRequires: libgudev1-devel glib2-devel libmbim-devel libqmi-devel systemd-devel
%if %{with vala}
BuildRequires: vala
%endif

Requires:      libmbim-utils libqmi-utils polkit
Requires:      %{name}-glib = %{version}-%{release}
%{?systemd_requires}

Conflicts: glib2 < %{glib2_version}
Conflicts: libqmi < %{qmi_version}
Conflicts: libmbim < %{mbim_version}

%description
This package provides ModemManager service which manages WWAN modems
and provides a consistent API for interacting with these devices to
client applications.

%package devel
Summary: Libraries and headers for adding ModemManager support to applications
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig

%description devel
This package provides various headers for accessing some ModemManager functionality
from applications.

%package glib
Summary: Libraries for adding ModemManager support to applications that use glib.
Requires: glib2 >= %{glib2_version}

%description glib
This package provides libraries that make it easier to use some ModemManager
functionality from applications that use glib.

%package glib-devel
Summary: Libraries and headers for adding ModemManager support to applications that use glib.
Requires: %{name} = %{version}-%{release}
Requires: %{name}-devel = %{version}-%{release}
Requires: %{name}-glib = %{version}-%{release}
Requires: glib2-devel >= %{glib2_version}
Requires: pkgconfig

%description glib-devel
This package provides various headers for accessing some ModemManager functionality
from glib applications.

%if %{with vala}
%package vala
Summary: Vala bindings for ModemManager
Requires: vala
Requires: %{name}-glib = %{version}-%{release}

%description vala
Vala bindings for ModemManager
%endif

%prep
%autosetup -n %{name}-%{version} -p1

%build
autoreconf -vif
%configure \
	--disable-rpath \
	--disable-silent-rules \
	--with-systemd-suspend-resume \
	--with-systemd-journal \
	--enable-more-warnings=no \
	--with-udev-base-dir=%{_prefix}/lib/udev \
	--enable-gtk-doc \
	--with-qmi=yes \
	--with-mbim=yes \
%ifarch aarch64
	--enable-plugin-qcom-soc \
%endif
	--disable-static \
	--with-polkit=permissive \
	--with-dist-version=%{version}-%{release} \
%if %{with vala}
	--enable-vala=yes
%else
	--enable-vala=no
%endif

%make_build

%check

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete

%find_lang %{name}

%post
%systemd_post ModemManager.service

%preun
%systemd_preun ModemManager.service

%postun
%systemd_postun ModemManager.service

%files -f %{name}.lang
%license COPYING
%doc README
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.ModemManager1.conf
%{_datadir}/dbus-1/system-services/org.freedesktop.ModemManager1.service
%attr(0755,root,root) %{_sbindir}/ModemManager
%attr(0755,root,root) %{_bindir}/mmcli
%dir %{_libdir}/%{name}
%attr(0755,root,root) %{_libdir}/%{name}/*.so*
%{_udevrulesdir}/*
%{_datadir}/polkit-1/actions/*.policy
%{_unitdir}/ModemManager.service
%{_datadir}/icons/hicolor/22x22/apps/*.png
%{_datadir}/bash-completion
%{_datadir}/ModemManager
%{_mandir}/man1/*
%{_mandir}/man8/*

%files devel
%{_includedir}/ModemManager/
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/dbus-1/interfaces/*.xml

%files glib
%license COPYING
%{_libdir}/libmm-glib.so.*
%{_libdir}/girepository-1.0/*.typelib

%files glib-devel
%{_libdir}/libmm-glib.so
%dir %{_includedir}/libmm-glib
%{_includedir}/libmm-glib/*.h
%{_libdir}/pkgconfig/mm-glib.pc
%{_datadir}/gtk-doc/html/*
%{_datadir}/gir-1.0/*.gir

%if %{with vala}
%files vala
%{_datadir}/vala/vapi/libmm-glib.*
%endif

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.20.2-4
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.20.2-3
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.20.2-2
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Jul 13 2023 cunshunxia <cunshunxia@tencent.com> - 1.20.2-1
- upgrade to 1.20.2

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.18.2-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.18.2-3
- Rebuilt for OpenCloudOS Stream 23

* Thu Feb 23 2023 Shuo Wang <abushwang@tencent.com> - 1.18.2-2
- enable vala

* Mon Nov 21 2022 Shuo Wang <abushwang@tencent.com> - 1.18.2-1
- initial build
